==> P6ProForEPPM-22.12.9.zip: P6ProForEPPM/Database/scripts/upgrade/PPM_22_12_09/ORPPM_P2101.sql <==

--Run Script as     
SET DEFINE OFF

--METADATA NAME:min_pro_version TYPE:FIELD TABLE_NAME:PREFER CHANGE:CREATE
DECLARE
  col_exists integer;
BEGIN
  select count(*) into col_exists from user_tab_columns where table_name = upper('PREFER') and column_name=upper('min_pro_version');
  if col_exists = 0
  then
    execute immediate 'ALTER TABLE PREFER add   min_pro_version  varchar2(10 CHAR) NULL
';
  end if;
END;         
/

--METADATA NAME:rsrc_role_match_flag TYPE:FIELD TABLE_NAME:PROJECT CHANGE:CREATE
DECLARE
  col_exists integer;
BEGIN
  select count(*) into col_exists from user_tab_columns where table_name = upper('PROJECT') and column_name=upper('rsrc_role_match_flag');
  if col_exists = 0
  then
    execute immediate 'ALTER TABLE PROJECT add   rsrc_role_match_flag  varchar2(1 CHAR) DEFAULT ''N'' NOT NULL
';
  end if;
END;         
/

--METADATA NAME:last_schedule_date TYPE:FIELD TABLE_NAME:PROJECT CHANGE:CREATE
DECLARE
  col_exists integer;
BEGIN
  select count(*) into col_exists from user_tab_columns where table_name = upper('PROJECT') and column_name=upper('last_schedule_date');
  if col_exists = 0
  then
    execute immediate 'ALTER TABLE PROJECT add   last_schedule_date  DATE NULL
';
  end if;
END;         
/



--METADATA TYPE:UP2 GROUP:2101to2102 NAME:MISC_UPDATES 
--METADATA TYPE:UP2 GROUP:2101to2102 NAME:MISC_UPDATES
update prefer set min_pro_version = null
/
/ 
--END TYPE:UP2 GROUP:2101to2102 NAME:MISC_UPDATES
--METADATA TYPE:UP2 GROUP:2104to2105 NAME:MISC_UPDATES 
--METADATA TYPE:UP2 GROUP:2104to2105 NAME:MISC_UPDATES
declare
 v_len NUMBER;
 v_import_point_web NUMBER;
 v_import_point_pro NUMBER;
 v_delete_point_web NUMBER;
 v_delete_point_pro NUMBER;
 v_delete_point NUMBER;
 v_extdep_point NUMBER;
 v_import_value blob;
 v_delete_value blob;
 v_start blob;
 v_end blob;
 v_final blob;
 cursor v is select view_id, view_data
 from viewprop 
 where view_type = 'VP_XML_IMP_DET_OPT'
 and view_data is not null;
BEGIN
 for rec in v loop
 v_len := dbms_lob.getlength(rec.view_data);
 if(v_len is not null and v_len > 0) then
  v_extdep_point := dbms_lob.instr(rec.view_data, utl_raw.cast_to_raw('P_EXTDEP') );
  if (v_extdep_point is null or v_extdep_point = 0) then
   v_import_point_web := dbms_lob.instr(rec.view_data, utl_raw.cast_to_raw('(0||P_TASKPRED(import_option|') );
   v_delete_point_pro := dbms_lob.instr(rec.view_data, utl_raw.cast_to_raw('(0||P_TASKPRED(delete_unref|') );

   if(v_import_point_web is not null and v_import_point_web > 0) then
    dbms_lob.createtemporary(v_final, true);
    dbms_lob.createtemporary(v_start, true);
    dbms_lob.createtemporary(v_end, true);
 
    dbms_lob.append(v_start, dbms_lob.substr(rec.view_data,v_import_point_web+48,1 ) );
    dbms_lob.append(v_end, dbms_lob.substr(rec.view_data,v_len,v_import_point_web+49 ) );
	
	v_delete_point_web := v_import_point_web+44;
   
    v_import_value := dbms_lob.substr(rec.view_data,1,v_import_point_web+29) ;
    v_delete_value := dbms_lob.substr(rec.view_data,1,v_delete_point_web) ;

    dbms_lob.append(v_final,v_start);
    dbms_lob.append(v_final,utl_raw.cast_to_raw('(0||P_EXTDEP(import_option|'));
    dbms_lob.append(v_final,v_import_value);
    dbms_lob.append(v_final,utl_raw.cast_to_raw('|delete_unref|'));
    dbms_lob.append(v_final,v_delete_value);
    dbms_lob.append(v_final,utl_raw.cast_to_raw(')())'));
    dbms_lob.append(v_final,v_end);
	update viewprop set view_data=v_final where view_id=rec.view_id;
	
	elsif(v_delete_point_pro is not null and v_delete_point_pro > 0) then
	dbms_lob.createtemporary(v_final, true);
    dbms_lob.createtemporary(v_start, true);
    dbms_lob.createtemporary(v_end, true);
 
    dbms_lob.append(v_start, dbms_lob.substr(rec.view_data,v_delete_point_pro+48,1 ) );
    dbms_lob.append(v_end, dbms_lob.substr(rec.view_data,v_len,v_delete_point_pro+49 ) );
	
    v_import_point_pro := v_delete_point_pro+44;
   
    v_delete_value := dbms_lob.substr(rec.view_data,1,v_delete_point_pro+28) ;
    v_import_value := dbms_lob.substr(rec.view_data,1,v_import_point_pro) ;

    dbms_lob.append(v_final,v_start);
    dbms_lob.append(v_final,utl_raw.cast_to_raw('(0||P_EXTDEP(delete_unref|'));
    dbms_lob.append(v_final,v_delete_value);
    dbms_lob.append(v_final,utl_raw.cast_to_raw('|import_option|'));
    dbms_lob.append(v_final,v_import_value);
    dbms_lob.append(v_final,utl_raw.cast_to_raw(')())'));
    dbms_lob.append(v_final,v_end);
	update viewprop set view_data=v_final where view_id=rec.view_id;
	end if;    
    commit;
  end if;
 end if;
end loop;
EXCEPTION
 WHEN OTHERS THEN
  NULL;
end;
/

/ 
--END TYPE:UP2 GROUP:2104to2105 NAME:MISC_UPDATES
--METADATA TYPE:UP2 GROUP:2108to2109 NAME:MISC_UPDATES 
--METADATA TYPE:UP2 GROUP:2108to2109 NAME:MISC_UPDATES
DECLARE
  constraint_exists integer;
BEGIN
  select count(*) into constraint_exists from user_constraints where table_name = upper('PROJECT') and constraint_name=upper('CK_PROJ_RSRC_ROLE_MATCH_FLAG');
  if constraint_exists = 0
  then
    EXECUTE IMMEDIATE 'ALTER TABLE PROJECT
    ADD CONSTRAINT ck_proj_rsrc_role_match_flag CHECK (rsrc_role_match_flag in (''Y'', ''N''))';
  end if;
END;         
/
/ 
--END TYPE:UP2 GROUP:2108to2109 NAME:MISC_UPDATES
--METADATA TYPE:UP2 GROUP:2109to2110 NAME:MISC_UPDATES 
--METADATA TYPE:UP2 GROUP:2109to2110 NAME:MISC_UPDATES
select 1 from prefer
/
/ 
--END TYPE:UP2 GROUP:2109to2110 NAME:MISC_UPDATES
--METADATA TYPE:UP2 GROUP:2112to2201 NAME:MISC_UPDATES 
--METADATA TYPE:UP2 GROUP:2112to2201 NAME:MISC_UPDATES
update settings set setting_value = 'https://docs.oracle.com/cd/F51301_01/client_help/' where setting_name = 'OnlineHelpRootUrl'
/
/ 
--END TYPE:UP2 GROUP:2112to2201 NAME:MISC_UPDATES
--METADATA TYPE:UP2 GROUP:2202to2203 NAME:MISC_UPDATES 
--METADATA TYPE:UP2 GROUP:2202to2203 NAME:MISC_UPDATES
update settings set setting_value = 'https://docs.oracle.com/cd/F51303_01/client_help/' where setting_name = 'OnlineHelpRootUrl'
/
/ 
--END TYPE:UP2 GROUP:2202to2203 NAME:MISC_UPDATES
--METADATA TYPE:UP2 GROUP:2204to2205 NAME:MISC_UPDATES 
--METADATA TYPE:UP2 GROUP:2204to2205 NAME:MISC_UPDATES
update udftype 
set DISP_DATA_FLAG='Y', DISP_INDICATOR_FLAG='N' 
where table_name = 'PROJECT' 
and  udf_type_label in ('Approved Budget', 'Bugs Fixed', 'Business Case #', 'Change', 'Comments', 'Cost Status', 'Cost-Budget Variance',
 'Count', 'Current Year Approved Hours', 'Customer Satisfaction', 'Date', 'Delivery Date', 'Description', 'Effort (FTE)', 'Est. Costs', 'Estimated IT Costs $',
 'Estimated PC Costs $', 'Expected Finish', 'Forecasted Revenue', 'FTE Reduction', 'Hardware Budget', 'Next Year Approved Hours',
 'NPV $', 'Original Budget', 'Overall Status', 'Phone', 'Planned Finish', 'Prev. Year Approved Hours', 'Projected Final Cost', 'Proposed Budget', 'Quality',
 'Risk', 'Risk Assessment', 'ROI (%)', 'Safety', 'Schedule Status', 'Scope Changes', 'Scope Status', 'Six Sigma Customer Inquires Reduced',
 'Six Sigma Defects', 'Six Sigma Estimated FTE Saved', 'Six Sigma Total Savings ($)', 'Stored Proj Score', 'sys_schedule_freeze', 'sys_scope_freeze',
 'sys_workdown', 'sys_workdown_date', 'sys_workprocess', 'Target %', 'Total Benefits $')
/
--METADATA TYPE:UP2 GROUP:2204to2205 NAME:MISC_UPDATES
update udftype 
set DISP_DATA_FLAG='Y', DISP_INDICATOR_FLAG='Y' 
where table_name = 'PROJECT' 
and  udf_type_label in ('forecasted remaining duration', 'Market Risk  (20%)', 'Previous Score', 'Product Innovation  (25%)', 'Product Reliability',
 'Product ROI  (30%)', 'Production Impact  (15%)', 'Risk Level', 'Total Weighted Score')
/
--METADATA TYPE:UP2 GROUP:2204to2205 NAME:MISC_UPDATES
update udftype 
set DISP_DATA_FLAG='N', DISP_INDICATOR_FLAG='Y' 
where table_name = 'PROJECT' 
and  udf_type_label in ('Cost Variance', 'Current Score', 'Financial ROI  (30%)', 'Overall Score  (weighted)', 'Resource Capacity  (10%)',
'Resource Constraints  (20%)', 'Strategy Alignment  (40%)', 'Technology Fit  (10%)')
/
--METADATA TYPE:UP2 GROUP:2204to2205 NAME:MISC_UPDATES
update udftype
set disp_data_flag='Y', disp_indicator_flag='N', udf_code_short_len=7
where table_name = 'PROJECT' 
and logical_data_type like '%DATE'
/

/ 
--END TYPE:UP2 GROUP:2204to2205 NAME:MISC_UPDATES
--METADATA TYPE:UP2 GROUP:2211to2212 NAME:MISC_UPDATES 
--METADATA TYPE:UP2 GROUP:2211to2212 NAME:MISC_UPDATES
declare
v_tbs varchar2(40);
begin
select tablespace_name into v_tbs from user_ts_quotas where tablespace_name like '%NDX%' and rownum =1;

execute immediate 'ALTER TABLE TASKUSER DROP CONSTRAINT PK_TASKUSER' ;

execute immediate 'ALTER TABLE TASKUSER ADD CONSTRAINT PK_TASKUSER PRIMARY KEY (task_id) USING INDEX TABLESPACE '||v_tbs ;

exception when others then
null;
end;
/

/ 
--END TYPE:UP2 GROUP:2211to2212 NAME:MISC_UPDATES
--METADATA TYPE:UP2 GROUP:221201to221202 NAME:MISC_UPDATES 
--METADATA TYPE:UP2 GROUP:221201to221202 NAME:MISC_UPDATES
UPDATE settings SET setting_value = 'https://docs.oracle.com/cd/F51303_01/client_help/' WHERE setting_name='OnlineHelpRootUrl'
/
/ 
--END TYPE:UP2 GROUP:221201to221202 NAME:MISC_UPDATES
update prefer set database_version='PPMDB,2212.0009.0000.0000'
/

--METADATA TYPE:MIN_PRO_VERSION_UPDATE DBTYPE:PPMDB TO:22.12.00
update prefer set min_pro_version='22.12.00'
/
commit
/

==> P6ProForEPPM-23.12.6.zip: P6ProForEPPM/Database/scripts/upgrade/PPM_23_12_06/ORPPM_P2101.sql <==

--Run Script as     
SET DEFINE OFF

--METADATA NAME:min_pro_version TYPE:FIELD TABLE_NAME:PREFER CHANGE:CREATE
DECLARE
  col_exists integer;
BEGIN
  select count(*) into col_exists from user_tab_columns where table_name = upper('PREFER') and column_name=upper('min_pro_version');
  if col_exists = 0
  then
    execute immediate 'ALTER TABLE PREFER add   min_pro_version  varchar2(10 CHAR) NULL
';
  end if;
END;         
/

--METADATA NAME:rsrc_role_match_flag TYPE:FIELD TABLE_NAME:PROJECT CHANGE:CREATE
DECLARE
  col_exists integer;
BEGIN
  select count(*) into col_exists from user_tab_columns where table_name = upper('PROJECT') and column_name=upper('rsrc_role_match_flag');
  if col_exists = 0
  then
    execute immediate 'ALTER TABLE PROJECT add   rsrc_role_match_flag  varchar2(1 CHAR) DEFAULT ''N'' NOT NULL
';
  end if;
END;         
/

--METADATA NAME:last_schedule_date TYPE:FIELD TABLE_NAME:PROJECT CHANGE:CREATE
DECLARE
  col_exists integer;
BEGIN
  select count(*) into col_exists from user_tab_columns where table_name = upper('PROJECT') and column_name=upper('last_schedule_date');
  if col_exists = 0
  then
    execute immediate 'ALTER TABLE PROJECT add   last_schedule_date  DATE NULL
';
  end if;
END;         
/

--METADATA NAME:private_loc TYPE:FIELD TABLE_NAME:DOCUMENT CHANGE:ALTER
ALTER TABLE DOCUMENT modify private_loc varchar2(4000 CHAR)
/

--METADATA NAME:public_loc TYPE:FIELD TABLE_NAME:DOCUMENT CHANGE:ALTER
ALTER TABLE DOCUMENT modify public_loc varchar2(4000 CHAR)
/



--METADATA TYPE:UP2 GROUP:2101to2102 NAME:MISC_UPDATES 
--METADATA TYPE:UP2 GROUP:2101to2102 NAME:MISC_UPDATES
update prefer set min_pro_version = null
/
/ 
--END TYPE:UP2 GROUP:2101to2102 NAME:MISC_UPDATES
--METADATA TYPE:UP2 GROUP:2104to2105 NAME:MISC_UPDATES 
--METADATA TYPE:UP2 GROUP:2104to2105 NAME:MISC_UPDATES
declare
 v_len NUMBER;
 v_import_point_web NUMBER;
 v_import_point_pro NUMBER;
 v_delete_point_web NUMBER;
 v_delete_point_pro NUMBER;
 v_delete_point NUMBER;
 v_extdep_point NUMBER;
 v_import_value blob;
 v_delete_value blob;
 v_start blob;
 v_end blob;
 v_final blob;
 cursor v is select view_id, view_data
 from viewprop 
 where view_type = 'VP_XML_IMP_DET_OPT'
 and view_data is not null;
BEGIN
 for rec in v loop
 v_len := dbms_lob.getlength(rec.view_data);
 if(v_len is not null and v_len > 0) then
  v_extdep_point := dbms_lob.instr(rec.view_data, utl_raw.cast_to_raw('P_EXTDEP') );
  if (v_extdep_point is null or v_extdep_point = 0) then
   v_import_point_web := dbms_lob.instr(rec.view_data, utl_raw.cast_to_raw('(0||P_TASKPRED(import_option|') );
   v_delete_point_pro := dbms_lob.instr(rec.view_data, utl_raw.cast_to_raw('(0||P_TASKPRED(delete_unref|') );

   if(v_import_point_web is not null and v_import_point_web > 0) then
    dbms_lob.createtemporary(v_final, true);
    dbms_lob.createtemporary(v_start, true);
    dbms_lob.createtemporary(v_end, true);
 
    dbms_lob.append(v_start, dbms_lob.substr(rec.view_data,v_import_point_web+48,1 ) );
    dbms_lob.append(v_end, dbms_lob.substr(rec.view_data,v_len,v_import_point_web+49 ) );
	
	v_delete_point_web := v_import_point_web+44;
   
    v_import_value := dbms_lob.substr(rec.view_data,1,v_import_point_web+29) ;
    v_delete_value := dbms_lob.substr(rec.view_data,1,v_delete_point_web) ;

    dbms_lob.append(v_final,v_start);
    dbms_lob.append(v_final,utl_raw.cast_to_raw('(0||P_EXTDEP(import_option|'));
    dbms_lob.append(v_final,v_import_value);
    dbms_lob.append(v_final,utl_raw.cast_to_raw('|delete_unref|'));
    dbms_lob.append(v_final,v_delete_value);
    dbms_lob.append(v_final,utl_raw.cast_to_raw(')())'));
    dbms_lob.append(v_final,v_end);
	update viewprop set view_data=v_final where view_id=rec.view_id;
	
	elsif(v_delete_point_pro is not null and v_delete_point_pro > 0) then
	dbms_lob.createtemporary(v_final, true);
    dbms_lob.createtemporary(v_start, true);
    dbms_lob.createtemporary(v_end, true);
 
    dbms_lob.append(v_start, dbms_lob.substr(rec.view_data,v_delete_point_pro+48,1 ) );
    dbms_lob.append(v_end, dbms_lob.substr(rec.view_data,v_len,v_delete_point_pro+49 ) );
	
    v_import_point_pro := v_delete_point_pro+44;
   
    v_delete_value := dbms_lob.substr(rec.view_data,1,v_delete_point_pro+28) ;
    v_import_value := dbms_lob.substr(rec.view_data,1,v_import_point_pro) ;

    dbms_lob.append(v_final,v_start);
    dbms_lob.append(v_final,utl_raw.cast_to_raw('(0||P_EXTDEP(delete_unref|'));
    dbms_lob.append(v_final,v_delete_value);
    dbms_lob.append(v_final,utl_raw.cast_to_raw('|import_option|'));
    dbms_lob.append(v_final,v_import_value);
    dbms_lob.append(v_final,utl_raw.cast_to_raw(')())'));
    dbms_lob.append(v_final,v_end);
	update viewprop set view_data=v_final where view_id=rec.view_id;
	end if;    
    commit;
  end if;
 end if;
end loop;
EXCEPTION
 WHEN OTHERS THEN
  NULL;
end;
/

/ 
--END TYPE:UP2 GROUP:2104to2105 NAME:MISC_UPDATES
--METADATA TYPE:UP2 GROUP:2108to2109 NAME:MISC_UPDATES 
--METADATA TYPE:UP2 GROUP:2108to2109 NAME:MISC_UPDATES
DECLARE
  constraint_exists integer;
BEGIN
  select count(*) into constraint_exists from user_constraints where table_name = upper('PROJECT') and constraint_name=upper('CK_PROJ_RSRC_ROLE_MATCH_FLAG');
  if constraint_exists = 0
  then
    EXECUTE IMMEDIATE 'ALTER TABLE PROJECT
    ADD CONSTRAINT ck_proj_rsrc_role_match_flag CHECK (rsrc_role_match_flag in (''Y'', ''N''))';
  end if;
END;         
/
/ 
--END TYPE:UP2 GROUP:2108to2109 NAME:MISC_UPDATES
--METADATA TYPE:UP2 GROUP:2109to2110 NAME:MISC_UPDATES 
--METADATA TYPE:UP2 GROUP:2109to2110 NAME:MISC_UPDATES
select 1 from prefer
/
/ 
--END TYPE:UP2 GROUP:2109to2110 NAME:MISC_UPDATES
--METADATA TYPE:UP2 GROUP:2112to2201 NAME:MISC_UPDATES 
--METADATA TYPE:UP2 GROUP:2112to2201 NAME:MISC_UPDATES
update settings set setting_value = 'https://docs.oracle.com/cd/F51301_01/client_help/' where setting_name = 'OnlineHelpRootUrl'
/
/ 
--END TYPE:UP2 GROUP:2112to2201 NAME:MISC_UPDATES
--METADATA TYPE:UP2 GROUP:2204to2205 NAME:MISC_UPDATES 
--METADATA TYPE:UP2 GROUP:2204to2205 NAME:MISC_UPDATES
update udftype 
set DISP_DATA_FLAG='Y', DISP_INDICATOR_FLAG='N' 
where table_name = 'PROJECT' 
and  udf_type_label in ('Approved Budget', 'Bugs Fixed', 'Business Case #', 'Change', 'Comments', 'Cost Status', 'Cost-Budget Variance',
 'Count', 'Current Year Approved Hours', 'Customer Satisfaction', 'Date', 'Delivery Date', 'Description', 'Effort (FTE)', 'Est. Costs', 'Estimated IT Costs $',
 'Estimated PC Costs $', 'Expected Finish', 'Forecasted Revenue', 'FTE Reduction', 'Hardware Budget', 'Next Year Approved Hours',
 'NPV $', 'Original Budget', 'Overall Status', 'Phone', 'Planned Finish', 'Prev. Year Approved Hours', 'Projected Final Cost', 'Proposed Budget', 'Quality',
 'Risk', 'Risk Assessment', 'ROI (%)', 'Safety', 'Schedule Status', 'Scope Changes', 'Scope Status', 'Six Sigma Customer Inquires Reduced',
 'Six Sigma Defects', 'Six Sigma Estimated FTE Saved', 'Six Sigma Total Savings ($)', 'Stored Proj Score', 'sys_schedule_freeze', 'sys_scope_freeze',
 'sys_workdown', 'sys_workdown_date', 'sys_workprocess', 'Target %', 'Total Benefits $')
/
--METADATA TYPE:UP2 GROUP:2204to2205 NAME:MISC_UPDATES
update udftype 
set DISP_DATA_FLAG='Y', DISP_INDICATOR_FLAG='Y' 
where table_name = 'PROJECT' 
and  udf_type_label in ('forecasted remaining duration', 'Market Risk  (20%)', 'Previous Score', 'Product Innovation  (25%)', 'Product Reliability',
 'Product ROI  (30%)', 'Production Impact  (15%)', 'Risk Level', 'Total Weighted Score')
/
--METADATA TYPE:UP2 GROUP:2204to2205 NAME:MISC_UPDATES
update udftype 
set DISP_DATA_FLAG='N', DISP_INDICATOR_FLAG='Y' 
where table_name = 'PROJECT' 
and  udf_type_label in ('Cost Variance', 'Current Score', 'Financial ROI  (30%)', 'Overall Score  (weighted)', 'Resource Capacity  (10%)',
'Resource Constraints  (20%)', 'Strategy Alignment  (40%)', 'Technology Fit  (10%)')
/
--METADATA TYPE:UP2 GROUP:2204to2205 NAME:MISC_UPDATES
update udftype
set disp_data_flag='Y', disp_indicator_flag='N', udf_code_short_len=7
where table_name = 'PROJECT' 
and logical_data_type like '%DATE'
/

/ 
--END TYPE:UP2 GROUP:2204to2205 NAME:MISC_UPDATES
--METADATA TYPE:UP2 GROUP:2211to2212 NAME:MISC_UPDATES 
--METADATA TYPE:UP2 GROUP:2211to2212 NAME:MISC_UPDATES
declare
v_tbs varchar2(40);
begin
select tablespace_name into v_tbs from user_ts_quotas where tablespace_name like '%NDX%' and rownum =1;

execute immediate 'ALTER TABLE TASKUSER DROP CONSTRAINT PK_TASKUSER' ;

execute immediate 'ALTER TABLE TASKUSER ADD CONSTRAINT PK_TASKUSER PRIMARY KEY (task_id) USING INDEX TABLESPACE '||v_tbs ;

exception when others then
null;
end;
/

/ 
--END TYPE:UP2 GROUP:2211to2212 NAME:MISC_UPDATES
--METADATA TYPE:UP2 GROUP:221201to221202 NAME:MISC_UPDATES 
--METADATA TYPE:UP2 GROUP:221201to221202 NAME:MISC_UPDATES
UPDATE settings SET setting_value = 'https://docs.oracle.com/cd/F51303_01/client_help/' WHERE setting_name='OnlineHelpRootUrl'
/
/ 
--END TYPE:UP2 GROUP:221201to221202 NAME:MISC_UPDATES
--METADATA TYPE:UP2 GROUP:2212to2301 NAME:MISC_UPDATES 
---METADATA TYPE:UP2 GROUP:2212to2301 NAME:MISC_UPDATES
update settings set setting_value = 'https://docs.oracle.com/cd/F74771_01/client_help/' where setting_name = 'OnlineHelpRootUrl'
/
/ 
--END TYPE:UP2 GROUP:2212to2301 NAME:MISC_UPDATES
--METADATA TYPE:UP2 GROUP:2311to2312 NAME:MISC_UPDATES 
--METADATA TYPE:UP2 GROUP:2311to2312 NAME:MISC_UPDATES
UPDATE Project
SET Def_Duration_Type = 'DT_FixedDUR2',
    Task_Code_Prefix = 'A',
    Task_Code_Base = 1000
WHERE Project_Flag = 'N'
      AND Orig_Proj_Id IS NULL
      AND ((Proj_Short_Name = 'EPS'
            OR Proj_Short_Name = 'Enterprise')
           OR Proj_Id = (
  SELECT MIN (Proj_Id)
  FROM Project P
  WHERE Project_Flag = 'N'
        AND Orig_Proj_Id IS NULL
))
/

/ 
--END TYPE:UP2 GROUP:2311to2312 NAME:MISC_UPDATES
--METADATA TYPE:UP2 GROUP:231201to231202 NAME:MISC_UPDATES 
--METADATA TYPE:UP2 GROUP:231201to231202 NAME:MISC_UPDATES
UPDATE settings SET setting_value = 'https://docs.oracle.com/cd/F74771_01/client_help/' WHERE setting_name='OnlineHelpRootUrl'
/
/ 
--END TYPE:UP2 GROUP:231201to231202 NAME:MISC_UPDATES
update prefer set database_version='PPMDB,2312.0006.0000.0000'
/

--METADATA TYPE:MIN_PRO_VERSION_UPDATE DBTYPE:PPMDB TO:23.10.00
update prefer set min_pro_version='23.10.00'
/
commit
/
